*************
API Reference
*************

The ur_rtde library API consists of the following parts:

* :ref:`rtde_control_interface.h <rtde-control-api>`: The RTDE control interface
* :ref:`rtde_receive_interface.h <rtde-receive-api>`: The RTDE receive interface
* :ref:`rtde_io_interface.h <rtde-io-api>`: The RTDE IO interface
* :ref:`rtde.h <rtde-api>`: The RTDE class
* :ref:`script_client.h <script-client-api>`: Script client
* :ref:`dashboard_client.h <dashboard-client-api>`: Dashboard client
* :ref:`robotiq_gripper.h <robotiq-gripper-api>`: Robotiq gripper interface

.. _rtde-control-api:

RTDE Control Interface API
==========================

.. doxygenclass:: ur_rtde::RTDEControlInterface
    :project: ur_rtde
    :path: ../doxygen/xml
    :members:

.. _rtde-receive-api:

RTDE Receive Interface API
==========================

.. doxygenclass:: ur_rtde::RTDEReceiveInterface
    :project: ur_rtde
    :path: ../doxygen/xml
    :members:
    :undoc-members:

.. _rtde-io-api:

RTDE IO Interface API
==========================

.. doxygenclass:: ur_rtde::RTDEIOInterface
    :project: ur_rtde
    :path: ../doxygen/xml
    :members:

.. _rtde-api:

RTDE Class API
==============

.. doxygenclass:: ur_rtde::RTDE
    :project: ur_rtde
    :path: ../doxygen/xml
    :members:
    :undoc-members:

.. _script-client-api:

Script Client API
=================

.. doxygenclass:: ur_rtde::ScriptClient
    :project: ur_rtde
    :path: ../doxygen/xml
    :members:
    :undoc-members:

.. _dashboard-client-api:

Dashboard Client API
====================

.. doxygenclass:: ur_rtde::DashboardClient
    :project: ur_rtde
    :path: ../doxygen/xml
    :members:
    :undoc-members:

.. _robotiq-gripper-api:

Robotiq Gripper API
===================

.. doxygenclass:: ur_rtde::RobotiqGripper
    :project: ur_rtde
    :path: ../doxygen/xml
    :members:
    :undoc-members: